summaryrefslogtreecommitdiffstats
path: root/karm/task.h
diff options
context:
space:
mode:
Diffstat (limited to 'karm/task.h')
-rw-r--r--karm/task.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/karm/task.h b/karm/task.h
index acf2cd998..53c7abcc9 100644
--- a/karm/task.h
+++ b/karm/task.h
@@ -46,20 +46,20 @@ class Task : public TQObject, public TQListViewItem
public:
//@{ constructors
Task( const TQString& taskame, long minutes, long sessionTime,
- DesktopList desktops, TaskView* tqparent = 0);
+ DesktopList desktops, TaskView* parent = 0);
Task( const TQString& taskame, long minutes, long sessionTime,
- DesktopList desktops, Task* tqparent = 0);
- Task( KCal::Todo* incident, TaskView* tqparent );
+ DesktopList desktops, Task* parent = 0);
+ Task( KCal::Todo* incident, TaskView* parent );
//@}
/* destructor */
~Task();
/** return tqparent Task or null in case of TaskView.
* same as TQListViewItem::tqparent()
*/
Task* firstChild() const { return (Task*)TQListViewItem::firstChild(); }
Task* nextSibling() const { return (Task*)TQListViewItem::nextSibling(); }
- Task* tqparent() const { return (Task*)TQListViewItem::tqparent(); }
+ Task* parent() const { return (Task*)TQListViewItem::parent(); }
/** Return task view for this task */
TaskView* taskView() const {
@@ -78,9 +78,9 @@ class Task : public TQObject, public TQListViewItem
*/
void setUid(const TQString uid);
/** cut Task out of tqparent Task or the TaskView */
void cut();
/** cut Task out of tqparent Task or the TaskView and into the
* destination Task */
void move(Task* destination);
/** insert Task into the destination Task */
@@ -162,7 +162,7 @@ class Task : public TQObject, public TQListViewItem
TQString name() const { return _name; };
/**
* Returns that task name, prefixed by tqparent tree up to root.
*
* Task names are seperated by a forward slash: /
*/
@@ -206,7 +206,7 @@ class Task : public TQObject, public TQListViewItem
TQString comment() const;
/** tells you whether this task is the root of the task tree */
- bool isRoot() const { return tqparent() == 0; }
+ bool isRoot() const { return parent() == 0; }
/** remove Task with all it's tqchildren
* @param activeTasks - list of aktive tasks
@@ -46,20 +46,20 @@ class Task : public TQObject, public TQListViewItem
/* destructor */
~Task();
- /** return tqparent Task or null in case of TaskView.
- * same as TQListViewItem::tqparent()
+ /** return parent Task or null in case of TaskView.
+ * same as TQListViewItem::parent()
*/
Task* firstChild() const { return (Task*)TQListViewItem::firstChild(); }
@@ -78,9 +78,9 @@ class Task : public TQObject, public TQListViewItem
*/
void setUid(const TQString uid);
- /** cut Task out of tqparent Task or the TaskView */
+ /** cut Task out of parent Task or the TaskView */
void cut();
@@ -78,9 +78,9 @@ class Task : public TQObject, public TQListViewItem
void cut();
- /** cut Task out of tqparent Task or the TaskView and into the
+ /** cut Task out of parent Task or the TaskView and into the
* destination Task */
void move(Task* destination);
@@ -162,7 +162,7 @@ class Task : public TQObject, public TQListViewItem
TQString name() const { return _name; };
/**
- * Returns that task name, prefixed by tqparent tree up to root.
+ * Returns that task name, prefixed by parent tree up to root.
*
* Task names are seperated by a forward slash: /